﻿using Syncfusion.ListView.XForms;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

using Xamarin.Forms;

namespace CustomSelection
{
    public partial class MainPage : ContentPage
    {
        #region Fields

        public SelectionViewModel ViewModel { get; set; }

        #endregion

        #region Constructor

        public MainPage()
        {
            InitializeComponent();
            ViewModel = new SelectionViewModel();
            listView.BindingContext = ViewModel;
            listView.ItemsSource = ViewModel.MusicInfos;
        }

        #endregion

        #region Private Methods

        private void UpdateSelectionTempate()
        {
            if (listView.SelectedItems.Count > 0)
            {
                listView.SelectionMode = SelectionMode.Multiple;
                listView.SelectionBackgroundColor = Color.Transparent;
                listView.SelectedItems.Clear();
            }
            else
            {
                listView.SelectionMode = SelectionMode.Single;
                listView.SelectionBackgroundColor = Color.FromRgb(228, 228, 228);
            }
        }

        private void UpdatMusicInfo()
        {
            var musicInfo = new MusicInfo();
            var random = new Random();
            musicInfo.MusicID = ViewModel.SelectedItem.MusicID;
            musicInfo.SongTitle = ViewModel.SongsNames[random.Next(1, 20)];
            musicInfo.SongAuther = ViewModel.SongAuthers[random.Next(1, 20)];
            musicInfo.SongSize = random.Next(50, 600).ToString() + "." + random.Next(1, 10) / 2 + "KB";
            musicInfo.SongThumbnail = ImageSource.FromResource("CustomSelection.Images.SongThumbnail.png");
            musicInfo.SelectedImage = ImageSource.FromResource("CustomSelection.Images.Selected.png");
            musicInfo.NotSelectedImage = ImageSource.FromResource("CustomSelection.Images.NotSelected.png");
        }

        #endregion

        #region CallBacks

        private void ListView_ItemHolding(object sender, ItemHoldingEventArgs e)
        {
            if (listView.SelectionMode != SelectionMode.Multiple)
                UpdateSelectionTempate();
        }

        private void ListView_OnSelectionChanged(object sender, ItemSelectionChangedEventArgs e)
        {
            if (listView.SelectionMode == SelectionMode.Multiple)
            {
                for (int i = 0; i < e.AddedItems.Count; i++)
                {
                    var item = e.AddedItems[i];
                    (item as MusicInfo).IsSelected = true;
                }
                for (int i = 0; i < e.RemovedItems.Count; i++)
                {
                    var item = e.RemovedItems[i];
                    (item as MusicInfo).IsSelected = false;
                }
            }

            UpdatMusicInfo();
        }

        #endregion
    }
}
